import { interact, replaceApiParams } from '../../utils'
import apis from '../../config/api'

export default {
  namespaced: true,
  state: {
    goodsList: [],
    goodsInfo: {},
    goodsTypes: [],
    goodsSpecs: [],
  },
  mutations: {
    updateList (state, payload) {
      state.goodsList = payload || []
    },
    updateInfo (state, payload) {
      state.goodsInfo = payload || {}
    },
    updateTypes (state, payload) {
      state.goodsTypes = payload || {}
    },
    updateSpecs (state, payload) {
      state.goodsSpecs = payload || {}
    }
  },
  actions: {
    GetGoodsList ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        interact(apis.goodsManager.getGoodsList, payload).then(res => {
          commit('updateList', res)
          resolve(res)
        }).catch(reject)
      })
    },
    GetGoodTypes ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        interact(apis.goodsManager.getGoodsTypeList, payload).then(res => {
          commit('updateTypes', res)
          resolve(res)
        }).catch(reject)
      })
    },
    GetGoodSpecs ({ commit }, payload) {
      interact(apis.goodsManager.getGoodsSpecList, payload).then(res => {
        commit('updateSpecs', res)
      })
    },
    GetGoodsByID ({ commit }, { id }) {
      interact(replaceApiParams(apis.goodsManager.getGoodsByID, { id })).then(res => {
        commit('updateInfo', res)
      })
    },
    AddGoods ({ commit }, payload) {
      interact(apis.goodsManager.addGoods, payload).then(res => {
        commit('updateInfo', res)
      })
    },
    UpdateGoods (_, payload) {
      interact(replaceApiParams(apis.goodsManager.updateGoods, { id: payload.GoodsId }), payload).then(x => x)
    },
    DelGoods (_, { id, callback }) {
      interact(replaceApiParams(apis.goodsManager.deleteGoods.url, { id: id })).then(callback)
    },
    SetNull ({ commit }) {
      commit('updateInfo', {})
    },
    UpdateInfo ({ commit }, payload) {
      commit('updateInfo', payload)
    }
  }
}
